This software is released under the GPL, see LICENSE.

To play izmon, you need to take 3 steps below.

1. install this library
2. import this library( 'from Izmon import Main' )
3. run script( 'Main.main()' )

To get more information about Izmon or learn about the specification of Izmon or contact us,
please look at the official reference ↓ (all of them are written in Japanese).
https://docs.google.com/spreadsheets/d/1bX43X_iltZBGkd1p2V-UCpBOe-Mpj0kI1CqSpalVTo4/

2023/03/06 akita nabe miso